# Genesis Foundation Comms

The `@genesislcap/foundation-comms` package is designed to streamline and enhance communication capabilities between web apps and Genesis servers. It provides a robust set of modules aimed at facilitating effective data exchange, authentication, and session management, among other utilities. With a focus on integration and ease of use, this library supports developers in building sophisticated, real-time communication features in their applications.

## API Documentation

For more detailed information on API and configurations, please refer to the [API documentation](docs/api/index.md) in the `docs/api` directory.

## Features

The library encompasses a broad range of features, including:

- **[Analytics Integration](src/analytics/README.md)** - Facilitates the collection and management of analytics data, enabling insights into application usage and user interactions.
- **[Authentication](src/auth/README.md)** - Provides mechanisms for user authentication and authorization, ensuring secure access control.
- **[Connection Management](src/connect/README.md)** - Offers utilities for managing connections, including real-time communications and data exchange.
- **[Credential Management](src/credentialManager/README.md)** - Aids in the secure storage and retrieval of user credentials, enhancing security and user experience.
- **[Data Source Integration](src/datasource/README.md)** - Simplifies the integration with various data sources, ensuring efficient data retrieval and management.
- **[Metadata Management](src/metadata/README.md)** - Allows for the handling and manipulation of metadata, facilitating dynamic content generation and customization.
- **[Session Management](src/session/README.md)** - Ensures robust session management capabilities, crucial for maintaining user state and session continuity.
- **[Storage Solutions](src/storage/README.md)** - Provides versatile storage options, including both persistent (Key-Value) and session-based storage mechanisms.
- **[Testing Utilities](src/testing/README.md)** - Includes tools and utilities for testing, ensuring reliability and performance of the communication features.
- **[User Management](src/user/README.md)** - Offers comprehensive tools for managing user information, preferences, and settings.
- **[Utility Functions](src/utils/README.md)** - A collection of utility functions to aid in common tasks and streamline development processes.

## Installation

To include `@genesislcap/foundation-comms` in your project, add it as a dependency in your `package.json` file and follow your project's routine for dependency installation.

```json
{
  "dependencies": {
    "@genesislcap/foundation-comms": "latest"
  }
}
```

## License

Note: this project provides front-end dependencies and uses licensed components listed in the next section; thus, licenses for those components are required during development. Contact [Genesis Global](https://genesis.global/contact-us/) for more details.

### Licensed components

Genesis low-code platform
