import type { SocketReconnectOptions } from './reconnectStrategy';
import type { SocketConnectOptions } from './socket.types';
/**
 * The connection status of the Genesis client.
 * @public
 */
export type ConnectionStatus = 'connected' | 'disconnected' | 'busy';
/**
 * Configuration options for the Connect (WS) instance.
 * @public
 */
export interface ConnectConfig {
    /**
     * Options for the initial connection.
     */
    connect: SocketConnectOptions;
    /**
     * Options for automatic reconnection on connection loss.
     */
    reconnect: SocketReconnectOptions;
    /**
     * Check for web socket url pattern.
     */
    isWebSocketExpression: RegExp;
}
/**
 * The default configuration for connecting to a WS service.
 * @public
 */
export declare const defaultConnectConfig: ConnectConfig;
/**
 * Configuration options for the Connect (WS) instance.
 * @internal
 */
export declare const ConnectConfig: import("@microsoft/fast-foundation").InterfaceSymbol<ConnectConfig>;
//# sourceMappingURL=connect.types.d.ts.map