import { JSONSerializer } from '@genesislcap/foundation-utils';
/**
 * The options object used when making an HTTP request.
 * @public
 */
export interface HttpRequestInit extends RequestInit {
    /**
     * A serializer function to transform the request body.
     * @remarks
     * This can be used to transform the request body to a specific format such as JSON or XML.
     */
    serializer?: JSONSerializer;
}
/**
 * An interface representing an HTTP client that can make GET and POST requests and return a promise with the response data.
 * @public
 */
export interface Http {
    get<T = any>(url: string, requestInit: HttpRequestInit): Promise<T>;
    post<T = any>(url: string, requestInit: HttpRequestInit): Promise<T>;
}
/**
 * The default implementation of the Http interface.
 * @public
 */
export declare class DefaultHttp implements Http {
    private serializer;
    constructor(serializer: JSONSerializer);
    get<T>(url: string, requestInit: HttpRequestInit): Promise<T>;
    post<T>(url: string, requestInit: HttpRequestInit): Promise<T>;
}
/**
 * The DI token for the Http interface.
 * @internal
 */
export declare const Http: import("@microsoft/fast-foundation").InterfaceSymbol<Http>;
//# sourceMappingURL=http.d.ts.map