import { Observer, Observable } from 'rxjs';
/**
 * Default number of reconnect attempts
 * @public
 */
export declare const MAX_RECONNECT_ATTEMPTS = 10;
/**
 * Socket reconnection strategies
 * @public
 */
export declare enum SocketReconnectStrategy {
    Linear = "linear",
    Exponential = "exponential"
}
/**
 * Socket reconnection options
 * @public
 */
export type SocketReconnectOptions = {
    reconnectAttempts?: number;
    /**
     * Interval between reconnect attempts
     * @public
     * @remarks
     * Time in milliseconds
     */
    reconnectInterval?: number;
    /**
     * Observer to notify when reconnection occurs
     * @public
     */
    reconnectObserver?: Observer<any>;
    /**
     * Reconnect stream subscriptions on reconnection
     * @public
     * @remarks
     * Whether to re-use existing wsMessageHandlers and wsMessages instances
     */
    reconnectStreams?: boolean;
    /**
     * Strategy to be used on reconnection
     * @public
     */
    reconnectStrategy?: SocketReconnectStrategy;
};
/**
 * Socket reconnection scheduler
 * @public
 * @param reconnectOptions - {@link SocketReconnectOptions} options
 * @param attempt - number of attempts
 * @returns milliseconds to wait before next reconnect attempt
 */
export type SocketReconnectScheduler = (reconnectOptions: SocketReconnectOptions, attempts?: number) => number;
/**
 * Generate reconnect interval based on scheduler
 * @public
 * @param reconnectOptions - {@link SocketReconnectOptions} options
 * @param scheduler - {@link SocketReconnectScheduler} function
 * @returns Observable<number>
 */
export declare const retryInterval: (reconnectOptions: SocketReconnectOptions, scheduler: SocketReconnectScheduler) => Observable<number>;
/**
 * Expontential Interval scheduler for reconnect
 * @public
 * @param reconnectOptions - {@link SocketReconnectOptions} options
 * @param attempt - number of attempts
 * @returns number of milliseconds that is a power of 2 ^ attempts * baseInterval
 */
export declare const exponentialScheduler: SocketReconnectScheduler;
/**
 * Linear Interval scheduler for reconnect
 * @public
 * @param reconnectOptions - {@link SocketReconnectOptions} options
 * @returns  number of milliseconds specified in reconnectOptions up to @see MAX_RECONNECT_INTERVAL
 */
export declare const linearScheduler: SocketReconnectScheduler;
//# sourceMappingURL=reconnectStrategy.d.ts.map