/**
 * A Serializer interface for serializing and deserializing objects.
 * @public
 */
export interface Serializer {
    /**
     * Serialize the given object into a string.
     * @param object - The object to serialize.
     * @returns The serialized string.
     * @deprecated - Use `serialize` from `JSONSerializer` from `@genesislcap/foundation-utils` instead.
     */
    serialize(object: any): string;
    /**
     * Deserialize a Response object into the expected type T.
     * @param response - The Response object to deserialize.
     * @returns A promise that resolves to the deserialized object of type T.
     * @deprecated - Use `deserialize` from `JSONSerializer` from `@genesislcap/foundation-utils` instead.
     */
    deserialize<T = any>(response: Response): Promise<T>;
    /**
     * Deserialize a MessageEvent object into the expected type T.
     * @param event - The MessageEvent object to deserialize.
     * @returns The deserialized object of type T.
     * @deprecated -Use `deserialize` from `JSONSerializer` from `@genesislcap/foundation-utils` instead.
     */
    deserialize<T = any>(event: MessageEvent): T;
    /**
     * Deserialize a string into the expected type T.
     * @param text - The string to deserialize.
     * @returns The deserialized object of type T.
     * @deprecated - Use `deserialize` from `JSONSerializer` from `@genesislcap/foundation-utils` instead.
     */
    deserialize<T = any>(text: string): T;
}
/**
 * The DI token for the Serializer interface.
 * @internal
 */
export declare const Serializer: import("@microsoft/fast-foundation").InterfaceSymbol<Serializer>;
//# sourceMappingURL=serializers.d.ts.map