import type { Observer } from 'rxjs';
import type { Message, PingMessage, PongMessage } from './message';
/**
 * The Socket connection options definition.
 * @public
 */
export type SocketConnectOptions = {
    /**
     * Experimental flag to force reconnection all error scenarios (1011, 1012, etc). Won't rely on reconnectAttempts value.
     * @experimental
     * @remarks
     * This will force the socket to reconnect if the connection is lost even on "final" errors. Only disconnects when directly calling reset()
     * @see Socket#reset
     */
    alwaysOn?: boolean;
    /**
     * An observer to receive notifications of incoming messages from the server.
     */
    connectObserver?: Observer<Message>;
    /**
     * Enable sending heartbeat messages to the server to prevent the connection from timing out.
     */
    enableHeartbeat?: boolean;
    /**
     * Enable logging of heartbeat messages.
     */
    enableHeartbeatLogging?: boolean;
    /**
     * Enable logging of incoming and outgoing WS messages.
     */
    enableMessageLogging?: boolean;
    /**
     * Interval between heartbeat messages
     * @remarks
     * Time in milliseconds
     */
    heartbeatInterval?: number;
    /**
     * Server will send resource level information
     */
    verboseHeartbeat?: boolean;
    /**
     * Called with the ping message before it is sent
     * @param message - The outgoing ping message.
     */
    heartbeatPingCallback?: (message: PingMessage) => void;
    /**
     * Called with the pong message after it is received
     * @param message - The incoming pong message.
     */
    heartbeatPongCallback?: (message: PongMessage) => void;
    /**
     * The path to a proxy server to use for the connection.
     */
    proxyPath?: string;
};
//# sourceMappingURL=socket.types.d.ts.map