/// <reference types="webappsec-credential-management" />
/**
 * The configuration options for the CredentialManager cookie
 * @public
 */
export interface CredentialManagerCookieConfig {
    path: string;
    name: string;
    expires: number | Date;
    storePasswords?: boolean;
}
/**
 * The configuration for the CredentialManager
 * @public
 */
export interface CredentialManagerConfig {
    cookie: CredentialManagerCookieConfig;
}
/**
 * Represents basic credentials for a user.
 * @public
 */
export type BasicCredentialsInput = {
    username: string;
    password: string;
};
/**
 * Represents refresh credentials for a user.
 * @public
 */
export type RefreshCredentialsInput = {
    username: string;
    refreshToken: string;
    mfaToken?: string;
};
/**
 * Represents SSO credentials for a user.
 * @public
 */
export type SSOCredentialsInput = {
    ssoToken: string;
};
/**
 * Represents user credentials.
 * @public
 */
export type CredentialData = PasswordCredentialData & {
    password?: string;
};
/**
 * Represents options for retrieving credentials.
 * @public
 */
export type GetCredentialOptions = CredentialRequestOptions & {};
/**
 * The DI key which can be used for explicit configuration by the host application
 * @internal
 */
export declare const CredentialManagerConfig: import("@microsoft/fast-foundation").InterfaceSymbol<CredentialManagerConfig>;
//# sourceMappingURL=credentialManager.types.d.ts.map