/**
 * Criteria filters to fields.
 *
 * @param filters - Concatenated criteria filters.
 *
 * @public
 * @remarks
 * For filtering REQUEST_SERVER resources. Maps concatenated criteria filters
 * from a grid to a request fields object. Date/datetime groovy expressions will
 * append `_FROM` and `_TO` onto field names appropriately
 *
 * eg: converts
 *
 * ```
 * foo == 'bar' &&
 * asd == 'zxc' &&
 * Expr.containsIgnoreCase(FIELD, 'abc') &&
 * Expr.dateIsToday(DATE) &&
 * Expr.dateTimeIsGreaterEqual(DATETIME, '20231110-03:23') &&
 * Expr.dateTimeIsLessEqual(DATETIME, '20231115-03:23')
 * ```
 *
 * into
 *
 * ```
 * {
 *   foo: 'bar',
 *   asd: 'zxc',
 *   FIELD: '*abc*',
 *   DATE_FROM: '20231110-00:00',
 *   DATE_TO: '20231111-00:00',
 *   DATETIME_FROM: '20231110-03:23',
 *   DATETIME_TO: '20231115-03:23',
 * }
 * ```
 */
export declare function criteriaFiltersToFields(filters: string): Record<string, string>;
//# sourceMappingURL=criteriaFiltersToFields.d.ts.map