import type { FilteredDataServerResult, RawDataServerResult } from '../metadata';
import type { DatasourceOptions } from './datasource.types';
/**
 * Default values for a DatasourceConfig
 * @public
 */
export declare class DatasourceDefaults {
    static readonly MAX_ROWS_250 = 250;
    static readonly MAX_VIEW_1000 = 1000;
    static readonly REQ_REP_POLLING_INTERVAL_MS = 10000;
    static readonly DATASERVER_ROW_ID = "ROW_REF";
    static readonly REQUEST_SERVER_ROW_ID = "RECORD_ID";
}
/**
 * DatasourceConfig DI interface.
 *
 * @public
 */
export interface DatasourceConfig {
    /**
     * The element to emit events from.
     *
     * @remarks
     * If omitted the document is used.
     */
    eventEmitter?: HTMLElement;
    options: DatasourceOptions;
    criteriaToFields(filters: string): Record<string, string>;
    dataServerResultFilter(result: RawDataServerResult, rowId?: string): FilteredDataServerResult;
}
/**
 * Default DatasourceConfig DI implementation.
 * @public
 */
export declare const defaultDatasourceConfig: DatasourceConfig;
/**
 * DatasourceConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export declare const DatasourceConfig: import("@microsoft/fast-foundation").InterfaceSymbol<DatasourceConfig>;
//# sourceMappingURL=datasource.config.d.ts.map