import type { Metadata, SchemaResponse } from './metadata.types';
/**
 * A Metadata cache definition
 * @public
 */
export interface MetadataCache {
    /**
     * A map of cached metadata, with resource names as keys and metadata as values.
     * @public
     */
    cachedMetadata: Map<string, Metadata>;
    /**
     * Returns the metadata for the specified resource name.
     * @public
     * @param resourceName - The name of the resource.
     * @returns The metadata for the specified resource name.
     */
    getMetadataFor(resourceName: string): Metadata;
    /**
     * Returns true if metadata exists for the specified resource name, otherwise false.
     * @public
     * @param resourceName - The name of the resource.
     * @returns True if metadata exists for the specified resource name, otherwise false.
     */
    hasMetadataFor(resourceName: string): boolean;
    /**
     * Sets the metadata for the specified resource name.
     * @public
     * @param resourceName - The name of the resource.
     * @param metadata - The metadata to set.
     */
    setMetadataFor(resourceName: string, metadata: Metadata): void;
}
/**
 * A JSON schema cache definition
 * @public
 */
export interface JsonSchemaCache {
    cachedJsonSchema: Map<string, SchemaResponse>;
    getJsonSchemaFor(resourceName: string): SchemaResponse;
    hasJsonSchemaFor(resourceName: string): boolean;
    setJsonSchemaFor(resourceName: string, schemaResponse: SchemaResponse): any;
}
/**
 * Union type of MetadataCache and JsonSchemaCache
 * @public
 */
export type MetaCache = MetadataCache & JsonSchemaCache;
/**
 * The default implementation for the MetaCache interface.
 * @public
 */
export declare class DefaultMetaCache implements MetaCache {
    cachedMetadata: Map<string, Metadata>;
    cachedJsonSchema: Map<string, SchemaResponse>;
    getMetadataFor(resourceName: string): Metadata;
    getJsonSchemaFor(resourceName: string): SchemaResponse;
    hasMetadataFor(resourceName: string): boolean;
    hasJsonSchemaFor(resourceName: string): boolean;
    setMetadataFor(resourceName: string, metadata: Metadata): void;
    setJsonSchemaFor(resourceName: string, schemaResponse: SchemaResponse): void;
}
/**
 * The DI token for the MetaCache interface.
 * @internal
 */
export declare const MetaCache: import("@microsoft/fast-foundation").InterfaceSymbol<MetaCache>;
//# sourceMappingURL=metadata.d.ts.map