import type { LogLevel } from '@genesislcap/foundation-utils';
import type { GenesisConnectEvents, MonitoredResourceChecks, MonitoredResourceDataLogon } from './types';
/**
 * NetworkMonitorConfig DI interface.
 *
 * @public
 */
export interface NetworkMonitorConfig {
    /**
     * Window events that invoke checks
     */
    windowEvents?: (keyof WindowEventHandlersEventMap)[];
    /**
     * Document events that invoke checks
     */
    documentEvents?: (keyof DocumentEventMap)[];
    /**
     * Genesis connect events that invoke checks
     */
    genesisConnectEvents?: GenesisConnectEvents[];
    /**
     * Ignored Genesis resources that will NOT invoke checks
     */
    ignoredGenesisResources?: string[];
    /**
     * Start delay in ms
     */
    startDelay?: number;
    /**
     * Periodic check internal in ms
     */
    checkInterval?: number;
    /**
     * Check timeout in ms
     */
    checkTimeout?: number;
    /**
     * Default resource checks function
     */
    resourceChecks?: MonitoredResourceChecks;
    /**
     * Default resource data logon function
     * @remarks
     * Used to re-attempt data logon on an unhealthy data server
     */
    resourceDataLogon?: MonitoredResourceDataLogon;
    /**
     * The element to emit events from
     */
    eventEmitter?: HTMLElement;
    /**
     * Default log level
     */
    logLevel?: LogLevel;
}
/**
 * Default NetworkMonitorConfig DI implementation.
 * @public
 */
export declare const defaultNetworkMonitorConfig: NetworkMonitorConfig;
/**
 * NetworkMonitorConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export declare const NetworkMonitorConfig: import("@microsoft/fast-foundation").InterfaceSymbol<NetworkMonitorConfig>;
//# sourceMappingURL=config.d.ts.map