import { TypedBroadcastChannel } from '@genesislcap/foundation-broadcast-channel';
import { GenesisResourcesEvents } from './types';
/**
 * GenesisResourcesConfig DI interface.
 * @public
 */
export interface GenesisResourcesConfig {
    /**
     * Treat unavailable/empty genesis resource sets as fatal errors.
     */
    throwWhenUnavailable?: boolean;
    /**
     * Treat unknown resources as fatal errors.
     */
    throwWhenUnknown?: boolean;
}
/**
 * Default GenesisResourcesConfig implementation.
 * @public
 */
export declare const defaultGenesisResourcesConfig: GenesisResourcesConfig;
/**
 * GenesisResourcesConfig DI key.
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export declare const GenesisResourcesConfig: import("@microsoft/fast-foundation").InterfaceSymbol<GenesisResourcesConfig>;
/**
 * GenesisResourcesChannel DI interface.
 * @example
 * ```ts
 * import { GenesisResourcesChannel } from '@genesislcap/foundation-comms';
 * ...
 * @GenesisResourcesChannel protected channel: GenesisResourcesChannel;
 * ...
 * this.channel.onmessage = (e) => {
 *  if (this.channel.isMessageType('resources-loaded', e)) {
 *    logger.debug('resources-loaded', e.data.detail);
 *    return;
 *  }
 * }
 * ...
 * this.channel.close();
 * ```
 * @public
 */
export interface GenesisResourcesChannel extends TypedBroadcastChannel<GenesisResourcesEvents> {
}
/**
 * GenesisResourcesChannel DI key.
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export declare const GenesisResourcesChannel: import("@microsoft/fast-foundation").InterfaceSymbol<TypedBroadcastChannel<GenesisResourcesEvents>>;
/**
 * Gets GenesisResourcesChannel from the DI container.
 *
 * @remarks
 * A utility method for host applications that are not using decorators or the DI container.
 *
 * @example
 * ```ts
 * import { getGenesisResourcesChannel } from '@genesislcap/foundation-comms';
 * ...
 * const channel = getGenesisResourcesChannel();
 * ...
 * channel.onmessage = (e) => {
 *  if (channel.isMessageType('resources-loaded', e)) {
 *    logger.debug('resources-loaded', e.data.detail);
 *    return;
 *  }
 * }
 * ...
 * channel.close();
 * ```
 * @public
 */
export declare function getGenesisResourcesChannel(): GenesisResourcesChannel;
//# sourceMappingURL=config.d.ts.map