import { MessageError } from '../../connect';
/**
 * KV Message types
 * @alpha
 */
export declare enum KVMessageType {
    REQ_KEY_VALUE_LIST = "REQ_KEY_VALUE_LIST",
    REQ_KEY_VALUE_READ = "REQ_KEY_VALUE_READ"
}
/**
 * KV Event Message types
 * @alpha
 */
export declare enum KVEventMessageType {
    EVENT_KEY_VALUE_PUT = "EVENT_KEY_VALUE_PUT",
    EVENT_KEY_VALUE_DELETE = "EVENT_KEY_VALUE_DELETE"
}
/**
 * KVValue type.
 * @alpha
 */
export type KVValue = string | ArrayBuffer;
/**
 * KeyValue interface.
 * @alpha
 */
export interface KeyValue<T = KVValue> {
    /**
     * Key
     * @alpha
     */
    key: string;
    /**
     * Value
     * @alpha
     */
    value?: T;
    /**
     * Time key expires.
     *
     * @privateRemarks
     * Should we clean up with lazy deletion, ie. wait until an access request?
     *
     * @alpha
     */
    expiration?: number;
    /**
     * Value should be encoded.
     * @alpha
     */
    base64?: boolean;
    /**
     * Additional metadata.
     * @alpha
     */
    metadata?: {
        [key: string]: unknown;
    };
}
/**
 * KeyValueTransfer interface.
 *
 * @alpha
 */
export interface KeyValueTransfer<T> {
    kv: KeyValue<T>;
    serialize?(value: unknown): unknown;
    deserialize?(value: unknown): Promise<T>;
}
/**
 * KVStorage type.
 * @alpha
 */
export type KVEventFailureResponse = {
    ERROR?: MessageError[];
    WARNING: any[];
};
//# sourceMappingURL=kv.types.d.ts.map