/**
 * The available ypes of authentication.
 * @public
 */
export var AuthType;
(function (AuthType) {
    AuthType["BASIC"] = "BASIC";
    AuthType["SSO"] = "SSO";
    AuthType["JWT"] = "JWT";
    AuthType["REFRESH"] = "REFRESH";
})(AuthType || (AuthType = {}));
/**
 * Represents an error that occurs during authentication.
 * @public
 */
export class AuthError extends Error {
    constructor(sent, received, message = 'Auth Failed \n') {
        super(message);
        this.sent = sent;
        this.received = received;
        Object.setPrototypeOf(this, AuthError.prototype);
    }
    isIgnorableError() {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        if ((_d = (_c = (_b = (_a = this.received) === null || _a === void 0 ? void 0 : _a.DETAILS) === null || _b === void 0 ? void 0 : _b.ERROR) === null || _c === void 0 ? void 0 : _c.toLowerCase()) === null || _d === void 0 ? void 0 : _d.includes('request needs the user to be logged')) {
            return true;
        }
        if ((_h = (_g = (_f = (_e = this.received) === null || _e === void 0 ? void 0 : _e.DETAILS) === null || _f === void 0 ? void 0 : _f.ERROR) === null || _g === void 0 ? void 0 : _g.toLowerCase()) === null || _h === void 0 ? void 0 : _h.includes('is not logged in')) {
            return true;
        }
        return false;
    }
    getMessageError() {
        var _a, _b;
        return Array.isArray((_a = this.received) === null || _a === void 0 ? void 0 : _a.ERROR)
            ? (_b = this.received) === null || _b === void 0 ? void 0 : _b.ERROR.map((error) => this.errorDetailFormatter(error)).join('\n')
            : '';
    }
    getDetailsError() {
        var _a, _b, _c, _d;
        return Array.isArray((_b = (_a = this.received) === null || _a === void 0 ? void 0 : _a.DETAILS) === null || _b === void 0 ? void 0 : _b.ERROR)
            ? (_d = (_c = this.received) === null || _c === void 0 ? void 0 : _c.DETAILS) === null || _d === void 0 ? void 0 : _d.ERROR.map((error) => this.errorDetailFormatter(error)).join('\n')
            : '';
    }
    hasPasswordExpiredError() {
        return this.hasErrorCode('PASSWORD_EXPIRED');
    }
    hasMFAError() {
        return this.hasErrorCode('MFA_REQUIRED') || this.hasErrorCode('MFA_FAILED');
    }
    hasErrorCode(code) {
        var _a, _b;
        return Array.isArray((_a = this.received) === null || _a === void 0 ? void 0 : _a.ERROR)
            ? (_b = this.received) === null || _b === void 0 ? void 0 : _b.ERROR.some((error) => error.CODE === code)
            : false;
    }
    errorDetailFormatter(error) {
        return `\n ${error.CODE}: \n ${error.TEXT}`;
    }
}
