import { __decorate } from "tslib";
import { User } from '@genesislcap/foundation-user';
import { observable } from '@microsoft/fast-element';
import { DI } from '@microsoft/fast-foundation';
import { BehaviorSubject } from 'rxjs';
/**
 * Default SocketStatus implementation.
 * @public
 */
export class DefaultSocketStatus {
    constructor() {
        this.isConfigured = false;
        this.isConnecting = false;
        this.isConnected = false;
        this.isReconnecting = false;
        this.reconnectionLimitReached = false;
        this.isConnectedSubject = new BehaviorSubject(this.isConnected);
    }
    /** {@inheritDoc SerializedSocketStatus.hasValidSession} */
    get hasValidSession() {
        return this.user.isAuthenticated;
    }
    get isDisconnected() {
        return !this.isConnected;
    }
    get isDisconnectedByServer() {
        return this.closedClean !== undefined ? !this.closedClean : false;
    }
    isConnectedChanged() {
        var _a;
        if (this.isConnected) {
            this.resetClosedState();
        }
        this.isConnecting = false;
        this.isReconnecting = false;
        (_a = this.isConnectedSubject) === null || _a === void 0 ? void 0 : _a.next(this.isConnected);
    }
    isReconnectingChanged() {
        if (this.isReconnecting) {
            this.reconnectionLimitReached = false;
        }
    }
    resetClosedState() {
        this.closedCode = undefined;
        this.closedReason = undefined;
        this.closedClean = undefined;
    }
    serialize() {
        return {
            isConfigured: this.isConfigured,
            isConnecting: this.isConnecting,
            isConnected: this.isConnected,
            isDisconnected: this.isDisconnected,
            isDisconnectedByServer: this.isDisconnectedByServer,
            isReconnecting: this.isReconnecting,
            reconnectionLimitReached: this.reconnectionLimitReached,
            hasValidSession: this.hasValidSession,
            closedCode: this.closedCode,
            closedReason: this.closedReason,
            closedClean: this.closedClean,
        };
    }
    onClose(event) {
        this.isConnected = false;
        this.closedCode = event.code;
        this.closedReason = event.reason;
        this.closedClean = event.wasClean;
    }
}
__decorate([
    observable
], DefaultSocketStatus.prototype, "isConfigured", void 0);
__decorate([
    observable
], DefaultSocketStatus.prototype, "isConnecting", void 0);
__decorate([
    observable
], DefaultSocketStatus.prototype, "isConnected", void 0);
__decorate([
    observable
], DefaultSocketStatus.prototype, "isReconnecting", void 0);
__decorate([
    observable
], DefaultSocketStatus.prototype, "reconnectionLimitReached", void 0);
__decorate([
    observable
], DefaultSocketStatus.prototype, "closedCode", void 0);
__decorate([
    observable
], DefaultSocketStatus.prototype, "closedReason", void 0);
__decorate([
    observable
], DefaultSocketStatus.prototype, "closedClean", void 0);
__decorate([
    User
], DefaultSocketStatus.prototype, "user", void 0);
/**
 * SocketStatus DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export const SocketStatus = DI.createInterface((x) => x.singleton(DefaultSocketStatus));
/**
 * Gets SocketStatus from the DI container.
 *
 * @remarks
 * A utility method for host applications that are not using decorators or the DI container.
 *
 * @example
 * ```ts
 * import { getSocketStatus } from '@genesislcap/foundation-comms';
 * ...
 * private socketStatus = getSocketStatus();
 * ```
 *
 * @public
 */
export function getSocketStatus() {
    return DI.getOrCreateDOMContainer().get(SocketStatus);
}
