import { DI } from '@microsoft/fast-foundation';
import { criteriaFiltersToFields } from './criteriaFiltersToFields';
import { dataServerResultFilter } from './dataServerResultFilter';
/**
 * Default values for a DatasourceConfig
 * @public
 */
export class DatasourceDefaults {
}
DatasourceDefaults.MAX_ROWS_250 = 250;
DatasourceDefaults.MAX_VIEW_1000 = 1000;
DatasourceDefaults.REQ_REP_POLLING_INTERVAL_MS = 10000;
DatasourceDefaults.DATASERVER_ROW_ID = 'ROW_REF';
DatasourceDefaults.REQUEST_SERVER_ROW_ID = 'RECORD_ID';
/**
 * Default DatasourceConfig DI implementation.
 * @public
 */
export const defaultDatasourceConfig = {
    options: {
        criteria: '',
        isSnapshot: false,
        maxRows: DatasourceDefaults.MAX_ROWS_250,
        maxView: DatasourceDefaults.MAX_VIEW_1000,
        pollingInterval: DatasourceDefaults.REQ_REP_POLLING_INTERVAL_MS,
        movingView: false,
        orderBy: '',
        resourceName: '',
        reverse: false,
    },
    criteriaToFields: criteriaFiltersToFields,
    dataServerResultFilter: dataServerResultFilter,
};
/**
 * DatasourceConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export const DatasourceConfig = DI.createInterface((x) => x.instance(defaultDatasourceConfig));
