import { __awaiter } from "tslib";
import { DI } from '@microsoft/fast-foundation';
import { getConnect, getSocket } from '../connect';
import { MessageType } from '../connect/message';
/**
 * Default NetworkMonitorConfig DI implementation.
 * @public
 */
export const defaultNetworkMonitorConfig = {
    windowEvents: ['online', 'offline', 'pageshow'],
    documentEvents: ['visibilitychange'],
    genesisConnectEvents: ['stream', 'commit'],
    ignoredGenesisResources: [],
    startDelay: 5000,
    checkInterval: 10000,
    checkTimeout: 3000,
    /**
     * The default when a custom check function is not explicitly provided for a resource.
     */
    resourceChecks: (sourceRef) => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        const connect = getConnect();
        const message = yield connect.getMoreColumns(sourceRef);
        const lastUpdated = Date.now();
        const lastMessage = message;
        const isConnected = (_a = (message === null || message === void 0 ? void 0 : message.MESSAGE_TYPE) === MessageType.MORE_COLUMNS_ACK) !== null && _a !== void 0 ? _a : false;
        return {
            isConnected,
            lastUpdated,
            lastMessage,
        };
    }),
    /**
     * The default when a custom data logon function is not explicitly provided for a resource.
     */
    resourceDataLogon: ({ message, functions }) => {
        const { onMessage, onError } = functions;
        getSocket().sendForStream(message, onMessage, onError);
    },
};
/**
 * NetworkMonitorConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export const NetworkMonitorConfig = DI.createInterface((x) => x.instance(defaultNetworkMonitorConfig));
