import { registerTypedBroadcastChannel, } from '@genesislcap/foundation-broadcast-channel';
import { DI } from '@microsoft/fast-foundation';
import { GenesisResourcesChannelId } from './types';
/**
 * Default GenesisResourcesConfig implementation.
 * @public
 */
export const defaultGenesisResourcesConfig = {
    throwWhenUnavailable: true,
    throwWhenUnknown: false,
};
/**
 * GenesisResourcesConfig DI key.
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export const GenesisResourcesConfig = DI.createInterface((x) => x.instance(defaultGenesisResourcesConfig));
/**
 * GenesisResourcesChannel DI key.
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export const GenesisResourcesChannel = registerTypedBroadcastChannel(GenesisResourcesChannelId);
/**
 * Gets GenesisResourcesChannel from the DI container.
 *
 * @remarks
 * A utility method for host applications that are not using decorators or the DI container.
 *
 * @example
 * ```ts
 * import { getGenesisResourcesChannel } from '@genesislcap/foundation-comms';
 * ...
 * const channel = getGenesisResourcesChannel();
 * ...
 * channel.onmessage = (e) => {
 *  if (channel.isMessageType('resources-loaded', e)) {
 *    logger.debug('resources-loaded', e.data.detail);
 *    return;
 *  }
 * }
 * ...
 * channel.close();
 * ```
 * @public
 */
export function getGenesisResourcesChannel() {
    return DI.getOrCreateDOMContainer().get(GenesisResourcesChannel);
}
